@@ -1,22 +1,11 @@
 /*
     knewstuff3/provider.cpp
-    Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (c) 2003 - 2007 Josef Spillner <spillner@kde.org>
-    Copyright (c) 2009 Jeremy Whiting <jpwhiting@kde.org>
-    Copyright (C) 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2002 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2003-2007 Josef Spillner <spillner@kde.org>
+    SPDX-FileCopyrightText: 2009 Jeremy Whiting <jpwhiting@kde.org>
+    SPDX-FileCopyrightText: 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "staticxmlprovider_p.h"
@@ -24,9 +13,10 @@
 #include "xmlloader.h"
 
 #include <knewstuffcore_debug.h>
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 #include <QTimer>
+#include <tagsfilterchecker.h>
 
 
 namespace KNSCore
@@ -44,8 +34,6 @@ QString StaticXmlProvider::id() const
 
 bool StaticXmlProvider::setProviderXML(const QDomElement &xmldata)
 {
-    qCDebug(KNEWSTUFFCORE) << "setting provider xml";
-
     if (xmldata.tagName() != QLatin1String("provider")) {
         return false;
     }
@@ -106,7 +94,7 @@ bool StaticXmlProvider::setProviderXML(const QDomElement &xmldata)
         mId = mDownloadUrls[mDownloadUrls.begin().key()].url();
     }
 
-    QTimer::singleShot(0, this, SLOT(slotEmitProviderInitialized()));
+    QTimer::singleShot(0, this, &StaticXmlProvider::slotEmitProviderInitialized);
 
     return true;
 }
@@ -200,6 +188,8 @@ void StaticXmlProvider::slotFeedFileLoaded(const QDomDocument &doc)
     const Provider::Filter filter = loader->property("filter").value<Provider::Filter>();
     const QString searchTerm = loader->property("searchTerm").toString();
 
+    TagsFilterChecker checker(tagFilter());
+    TagsFilterChecker downloadschecker(downloadTagFilter());
     element = doc.documentElement();
     QDomElement n;
     for (n = element.firstChildElement(); !n.isNull(); n = n.nextSiblingElement()) {
@@ -225,27 +215,46 @@ void StaticXmlProvider::slotFeedFileLoaded(const QDomDocument &doc)
             }
             cacheEntry = entry;
         }
-        mCachedEntries.append(entry);
 
-        if (searchIncludesEntry(entry)) {
-            switch(filter) {
-                case Installed:
-                    //This is dealth with in loadEntries separately
-                    Q_UNREACHABLE();
-                case Updates:
-                    if (entry.status() == KNS3::Entry::Updateable) {
-                        entries << entry;
+        if (checker.filterAccepts(entry.tags())) {
+            bool filterAcceptsDownloads = true;
+            if (entry.downloadCount() > 0) {
+                const auto downloadInfoList = entry.downloadLinkInformationList();
+                for (const KNSCore::EntryInternal::DownloadLinkInformation &dli : downloadInfoList) {
+                    if (downloadschecker.filterAccepts(dli.tags)) {
+                        filterAcceptsDownloads = true;
+                        break;
                     }
-                    break;
-                case ExactEntryId:
-                    if (entry.uniqueId() == searchTerm) {
-                        entries << entry;
-                    }
-                    break;
-                case None:
-                    entries << entry;
-                    break;
+                }
             }
+            if (filterAcceptsDownloads) {
+                mCachedEntries.append(entry);
+
+                if (searchIncludesEntry(entry)) {
+                    switch(filter) {
+                        case Installed:
+                            //This is dealth with in loadEntries separately
+                            Q_UNREACHABLE();
+                        case Updates:
+                            if (entry.status() == KNS3::Entry::Updateable) {
+                                entries << entry;
+                            }
+                            break;
+                        case ExactEntryId:
+                            if (entry.uniqueId() == searchTerm) {
+                                entries << entry;
+                            }
+                            break;
+                        case None:
+                            entries << entry;
+                            break;
+                    }
+                }
+            } else {
+                qCDebug(KNEWSTUFFCORE) << "Filter has excluded" << entry.name() << "on download filter" << downloadTagFilter();
+            }
+        } else {
+            qCDebug(KNEWSTUFFCORE) << "Filter has excluded" << entry.name() << "on entry filter" << tagFilter();
         }
     }
     emit loadingFinished(mCurrentRequest, entries);
@@ -286,7 +295,7 @@ void StaticXmlProvider::loadPayloadLink(const KNSCore::EntryInternal &entry, int
 EntryInternal::List StaticXmlProvider::installedEntries() const
 {
     EntryInternal::List entries;
-    foreach (const EntryInternal &entry, mCachedEntries) {
+    for (const EntryInternal &entry : qAsConst(mCachedEntries)) {
         if (entry.status() == KNS3::Entry::Installed || entry.status() == KNS3::Entry::Updateable) {
             entries.append(entry);
         }
