@@ -1,30 +1,21 @@
 /*
-    Copyright (C) 2008 Jeremy Whiting <jpwhiting@kde.org>
-    Copyright (C) 2010 Reza Fatahilah Shah <rshah0385@kireihana.com>
-    Copyright (C) 2010 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2008 Jeremy Whiting <jpwhiting@kde.org>
+    SPDX-FileCopyrightText: 2010 Reza Fatahilah Shah <rshah0385@kireihana.com>
+    SPDX-FileCopyrightText: 2010 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
+
 #include "itemsviewbasedelegate_p.h"
 
 #include "core/itemsmodel.h"
 
 #include "entrydetailsdialog_p.h"
 
+#include <QAction>
+
 #include <knewstuff_debug.h>
 #include <qstandardpaths.h>
-#include <kiconloader.h>
 
 namespace KNS3
 {
@@ -36,7 +27,6 @@ ItemsViewBaseDelegate::ItemsViewBaseDelegate(QAbstractItemView *itemView, KNSCor
     , m_iconInstall(QIcon::fromTheme(QStringLiteral("dialog-ok")))
     , m_iconUpdate(QIcon::fromTheme(QStringLiteral("system-software-update")))
     , m_iconDelete(QIcon::fromTheme(QStringLiteral("edit-delete")))
-    , m_noImage(SmallIcon(QStringLiteral("image-missing"), KIconLoader::SizeLarge, KIconLoader::DisabledState))
 {
     const QString framefile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kf5/knewstuff/pics/thumb_frame.png"));
     m_frameImage = QPixmap(framefile);
