@@ -1,21 +1,10 @@
 /*
     knewstuff3/ui/uploaddialog.cpp.
-    Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (c) 2009 Jeremy Whiting <jpwhiting@kde.org>
-    Copyright (C) 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
+    SPDX-FileCopyrightText: 2002 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2009 Jeremy Whiting <jpwhiting@kde.org>
+    SPDX-FileCopyrightText: 2009-2010 Frederik Gladhorn <gladhorn@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "uploaddialog.h"
@@ -30,18 +19,19 @@
 #include <QString>
 #include <QCoreApplication>
 
-#include <kiconloader.h>
-#include <kmessagebox.h>
-#include <klocalizedstring.h>
+#include <KIconLoader>
+#include <KMessageBox>
+#include <KLocalizedString>
 
-#include <kpixmapsequence.h>
-#include <kpixmapsequencewidget.h>
-#include <krun.h>
+#include <KPixmapSequence>
+#include <KPixmapSequenceWidget>
+#include <KIO/OpenUrlJob>
+#include <KIO/JobUiDelegate>
 
 #include <knewstuff_debug.h>
 #include <QLoggingCategory>
-#include <kconfig.h>
-#include <kconfiggroup.h>
+#include <KConfig>
+#include <KConfigGroup>
 #include <qstandardpaths.h>
 
 using namespace KNS3;
@@ -757,7 +747,9 @@ void UploadDialogPrivate::_k_contentAdded(Attica::BaseJob *baseJob)
 
 void UploadDialogPrivate::_k_openRegisterAccountWebpage(QString)
 {
-    KRun::runUrl(QUrl::fromUserInput(atticaHelper->provider().getRegisterAccountUrl()), QStringLiteral("text/html"), q, KRun::RunFlags());
+    KIO::OpenUrlJob *job = new KIO::OpenUrlJob(QUrl::fromUserInput(atticaHelper->provider().getRegisterAccountUrl()), QStringLiteral("text/html"));
+    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, q));
+    job->start();
 }
 
 void UploadDialogPrivate::doUpload(const QString &index, const QUrl &path)
