@@ -1,19 +1,8 @@
 /*
     This file is part of KNewStuff2.
-    Copyright (c) 2007 Josef Spillner <spillner@kde.org>
+    SPDX-FileCopyrightText: 2007 Josef Spillner <spillner@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
 #include "knewstuff2_download.h"
@@ -21,12 +10,11 @@
 #include <knewstuff2/core/coreengine.h>
 #include <knewstuff2/core/author.h>
 
-#include <kstandarddirs.h>
+#include <KStandardDirs>
 #include <QDebug>
 
 #include <QApplication>
 #include <QPushButton>
-#include <QLayout>
 #include <QListWidget>
 #include <QTabWidget>
 #include <QTableWidget>
